@@ -1,11 +1,11 @@
-from fusil.aggressivity import AggressivityAgent
 from fusil.mangle import MangleFile
+from fusil.tools import minmax
 
 class AutoMangle(MangleFile):
     def __init__(self, project, *args, **kw):
         MangleFile.__init__(self, project, *args, **kw)
-        AggressivityAgent(project)
         self.hard_max_op = 10000
+        self.hard_min_op = 0
         self.aggressivity = None
         self.fixed_size_factor = 1.0
 
@@ -29,14 +29,14 @@ class AutoMangle(MangleFile):
 
         # Display config
         count = len(data) * size_factor * self.fixed_size_factor
-        count = min(count, self.hard_max_op)
+        count = minmax(self.hard_min_op, count, self.hard_max_op)
         count = int(count * self.aggressivity)
-        self.config.max_op = max(count, 0)
-        self.config.min_op = max(int(self.config.max_op * 0.80), 0)
+        self.config.max_op = max(count, self.hard_min_op)
+        self.config.min_op = max(int(self.config.max_op * 0.80), self.hard_min_op)
         self.warning("operation#:%s..%s  operations=%s"
             % (self.config.min_op, self.config.max_op, self.config.operations))
 
-    def mangleData(self, data):
+    def mangleData(self, data, file_index):
         self.setupConf(data)
-        return MangleFile.mangleData(self, data)
+        return MangleFile.mangleData(self, data, file_index)
 
