@@ -4,9 +4,9 @@ from os import getpid
 from fusil.score import scoreLogFunc
 from time import time
 import re
-from fusil.os_tools import RUNNING_LINUX
+from ptrace.os_tools import RUNNING_LINUX
 if RUNNING_LINUX:
-    from fusil.linux.proc import readProcessLink
+    from ptrace.linux_proc import readProcessLink
 
 def dumpFileInfo(logger, file_obj):
     try:
@@ -35,7 +35,7 @@ class FileWatch(ProjectAgent):
         self.max_nb_line = (100, 1.0)
         self.last_seed = None
         self.log_not_matching = False
-        self.show_not_matching = False
+        self.show_not_matching = project.application().options.debug
         self.read_size = 4096
         self.cleanup_func = None
         self.max_process_time = 0.250   # second
@@ -116,10 +116,13 @@ class FileWatch(ProjectAgent):
 
     def prepareFile(self):
         dumpFileInfo(self, self.file_obj)
+        oldpos = self.file_obj.tell()
         if self.start == 'zero':
             self.file_obj.seek(0)
         elif self.start == 'end':
             self.file_obj.seek(0, 2)
+        self.file_seed = self.file_obj.tell()
+        self.file_obj.seek(oldpos)
 
     def splitlines(self, data):
         lines = data.splitlines(1)
@@ -193,7 +196,11 @@ class FileWatch(ProjectAgent):
                     self.warning("Too slow: proceed %s lines in %.1f sec"
                         % (count, duration))
                     return
+                oldpos = self.file_obj.tell()
+                self.file_obj.seek(self.file_seed)
                 data = self.file_obj.read(self.read_size)
+                self.file_seed = self.file_obj.tell()
+                self.file_obj.seek(oldpos)
                 if not data:
                     return
                 for line in self.splitlines(data):
