@@ -31,13 +31,20 @@ class MTA:
             logger = NullLogger()
         self.logger = logger
 
+class Options:
+    def __init__(self):
+        self.debug = False
+
 class Application:
-    pass
+    def __init__(self):
+        self.options = Options()
 
 class Project:
     def __init__(self, logger=None):
         self._mta = MTA(logger)
         self.mta = ref(self._mta)
+        self._application = Application()
+        self.application = ref(self._application)
 
     def registerAgent(self, agent):
         pass
