@@ -12,7 +12,7 @@ class ProcessTimeWatch(TimeWatch):
     def on_session_done(self, score):
         pass
 
-    def on_process_done(self, agent):
+    def on_process_done(self, agent, status):
         duration = time() - self.time0
         self.warning("Process done: duration=%.1f ms" % (duration*1000))
         self.setScore(duration)
