@@ -1,6 +1,6 @@
 from fusil.session_agent import SessionAgent
 from fusil.directory import Directory
-from os.path import basename, join as path_join
+from os.path import basename
 
 class SessionDirectory(SessionAgent, Directory):
     def __init__(self, session, directory):
@@ -10,9 +10,6 @@ class SessionDirectory(SessionAgent, Directory):
         Directory.__init__(self, directory)
         SessionAgent.__init__(self, session, "directory:%s" % basename(self.directory))
 
-    def uniqueFilename(self, name=None, count=None):
-        return self._uniqueFilename(self.directory, name, count)
-
     def init(self):
         self.info("Create directory: %s" % self.directory)
         self.mkdir()
