@@ -21,7 +21,7 @@ def setupProject(project):
     mangle.fixed_size_factor = 0.5
 
     process = IdentifyProcess(project,
-        ['/usr/bin/identify', '-verbose', None],
+        ['identify', '-verbose', None],
         timeout=2.0)
     WatchProcess(process, exitcode_score=-0.25)
 
