@@ -9,9 +9,10 @@ def setupProject(project):
     php = PhpSource(project)
     php.ignore_functions.add('posix_kill')
 
-    process = PhpProcess(project, ['/usr/bin/php'], timeout=10.0)
+    process = PhpProcess(project, ['php', '<source.php>'], timeout=10.0)
     watch = WatchProcess(process, exitcode_score=0.10)
-    watch.cpu.score_weight = 0.3
+    if watch.cpu:
+        watch.cpu.score_weight = 0.3
     stdout = WatchPhpStdout(process, php)
     stdout.max_nb_line = (5000, 1.0)
     del stdout.words['memory']
@@ -27,6 +28,7 @@ def setupProject(project):
         stdout.ignoreRegex("^Fatal error: Can't use function return value in ")
         stdout.ignoreRegex("^Fatal error: Class .* not found")
         stdout.ignoreRegex("^Parse error:")
+        stdout.ignoreRegex("sem_get.*Permission denied")
     else:
         stdout.score_weight = 0.3
 
@@ -168,7 +170,7 @@ class PhpSource(ProjectAgent):
 
 class PhpProcess(CreateProcess):
     def on_php_source(self, filename):
-        self.cmdline.arguments = ['/usr/bin/php', filename]
+        self.cmdline.arguments[1] = filename
         self.createProcess()
 
 # From "/usr/share/vim/vim71/syntax/php.vim" (vim 7.1)
