@@ -4,9 +4,8 @@ to parse PATH environement variable.
 """
 
 def setupProject(project):
-    process = ProjectProcess(project, ['/usr/bin/xterm', 'ls'], timeout=1.0)
-    process.env.copy('DISPLAY')
-    process.env.copy('HOME')
+    process = ProjectProcess(project, ['xterm', 'ls'], timeout=1.0)
+    setupX11Process(process)
     process.env.add(EnvVarLength('PATH', max_length=1000))
 
     WatchProcess(process, timeout_score=0)
@@ -16,4 +15,5 @@ from fusil.process.env import EnvVarLength
 from fusil.process.create import ProjectProcess
 from fusil.process.watch import WatchProcess
 from fusil.process.stdout import WatchStdout
+from fusil.x11 import setupX11Process
 
