@@ -36,9 +36,9 @@ def main():
 
     # Unit tests as reST
     testDoc('tests/file_watch_read.rst')
+    testDoc('tests/cmd_help_parser.rst')
 
     # Test documentation of some functions/classes
-    testModule("fusil.compatibility")
     testModule("fusil.tools")
 
 if __name__ == "__main__":
